@@ -204,7 +204,7 @@ class TaskRouter:
             if os.path.isfile(os.path.join(module_path, 'env.yaml')):
                 if not os.path.isdir(os.path.join(module_path, '.venv')):
                     # FIXME: this is not working
-                    os.system("python3 /app/venv/setup_custom_envs.py -l -p 1 -r " + module_path)
+                    os.system("python3 /app/venv-builder/setup_custom_envs.py -l -p 1 -r " + module_path)
 
                 routeur = singularize(self.root_package_path)
 
@@ -240,7 +240,7 @@ class TaskRouter:
 pipenv run python3 -c "
 import os
 os.environ['LD_LIBRARY_PATH'] = '/usr/local/nvidia/lib64:/usr/local/cuda/lib64:/opt/conda/lib'
-import PIL
+from PIL import Image
 import importlib.util
 spec = importlib.util.spec_from_file_location('/app/{module_path}', '/app/{module_path}/{model}.py')
 this_module = importlib.util.module_from_spec(spec)
@@ -250,7 +250,7 @@ output = this_module.predict(**{kwargs_str})
 #FIXME
 ## convert output to bytes
 ## move this to string comparison
-if isinstance(output, PIL.Image.Image):
+if isinstance(output, Image.Image):
     output.save('{output_tmp_result}', format='PNG')
 else:
     with open('{output_tmp_result}', 'w') as f:
